# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: parker.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nullabletypes_pb2 as nullabletypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='parker.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0cparker.proto\x12\x06xbospb\x1a\x13nullabletypes.proto\"\xff\x17\n\x0bParkerState\x12\x30\n\x18\x63ompressor_working_hours\x18\x01 \x01(\x0b\x32\x0e.xbospb.Double\x12(\n\x11on_standby_status\x18\x02 \x01(\x0b\x32\r.xbospb.Int64\x12#\n\x0clight_status\x18\x03 \x01(\x0b\x32\r.xbospb.Int64\x12(\n\x11\x61ux_output_status\x18\x04 \x01(\x0b\x32\r.xbospb.Int64\x12,\n\x14next_defrost_counter\x18\x05 \x01(\x0b\x32\x0e.xbospb.Double\x12/\n\x18\x64oor_switch_input_status\x18\x06 \x01(\x0b\x32\r.xbospb.Int64\x12\x30\n\x19multipurpose_input_status\x18\x07 \x01(\x0b\x32\r.xbospb.Int64\x12(\n\x11\x63ompressor_status\x18\x08 \x01(\x0b\x32\r.xbospb.Int64\x12,\n\x15output_defrost_status\x18\t \x01(\x0b\x32\r.xbospb.Int64\x12\"\n\x0b\x66\x61ns_status\x18\n \x01(\x0b\x32\r.xbospb.Int64\x12\'\n\x10output_k4_status\x18\x0b \x01(\x0b\x32\r.xbospb.Int64\x12+\n\x13\x63\x61\x62inet_temperature\x18\x0c \x01(\x0b\x32\x0e.xbospb.Double\x12.\n\x16\x65vaporator_temperature\x18\r \x01(\x0b\x32\x0e.xbospb.Double\x12-\n\x15\x61uxiliary_temperature\x18\x0e \x01(\x0b\x32\x0e.xbospb.Double\x12+\n\x14probe1_failure_alarm\x18\x0f \x01(\x0b\x32\r.xbospb.Int64\x12+\n\x14probe2_failure_alarm\x18\x10 \x01(\x0b\x32\r.xbospb.Int64\x12+\n\x14probe3_failure_alarm\x18\x11 \x01(\x0b\x32\r.xbospb.Int64\x12\x30\n\x19minimum_temperature_alarm\x18\x12 \x01(\x0b\x32\r.xbospb.Int64\x12/\n\x18maximum_temperture_alarm\x18\x13 \x01(\x0b\x32\r.xbospb.Int64\x12:\n#condensor_temperature_failure_alarm\x18\x14 \x01(\x0b\x32\r.xbospb.Int64\x12*\n\x13\x63ondensor_pre_alarm\x18\x15 \x01(\x0b\x32\r.xbospb.Int64\x12!\n\ndoor_alarm\x18\x16 \x01(\x0b\x32\r.xbospb.Int64\x12/\n\x18multipurpose_input_alarm\x18\x17 \x01(\x0b\x32\r.xbospb.Int64\x12/\n\x18\x63ompressor_blocked_alarm\x18\x18 \x01(\x0b\x32\r.xbospb.Int64\x12*\n\x13power_failure_alarm\x18\x19 \x01(\x0b\x32\r.xbospb.Int64\x12&\n\x0frtc_error_alarm\x18\x1a \x01(\x0b\x32\r.xbospb.Int64\x12\x33\n\x1c\x65nergy_saving_regulator_flag\x18\x1b \x01(\x0b\x32\r.xbospb.Int64\x12=\n&energy_saving_real_time_regulator_flag\x18\x1c \x01(\x0b\x32\r.xbospb.Int64\x12\x35\n\x1eservice_request_regulator_flag\x18\x1d \x01(\x0b\x32\r.xbospb.Int64\x12\x30\n\x19on_standby_regulator_flag\x18\x1e \x01(\x0b\x32\r.xbospb.Int64\x12\x37\n new_alarm_to_read_regulator_flag\x18\x1f \x01(\x0b\x32\r.xbospb.Int64\x12\x34\n\x1d\x64\x65\x66rost_status_regulator_flag\x18  \x01(\x0b\x32\r.xbospb.Int64\x12&\n\x0f\x61\x63tive_setpoint\x18! \x01(\x0b\x32\r.xbospb.Int64\x12)\n\x12time_until_defrost\x18\" \x01(\x0b\x32\r.xbospb.Int64\x12.\n\x17\x63urrent_defrost_counter\x18# \x01(\x0b\x32\r.xbospb.Int64\x12\'\n\x10\x63ompressor_delay\x18$ \x01(\x0b\x32\r.xbospb.Int64\x12,\n\x15num_alarms_in_history\x18% \x01(\x0b\x32\r.xbospb.Int64\x12+\n\x14\x65nergy_saving_status\x18& \x01(\x0b\x32\r.xbospb.Int64\x12-\n\x16service_request_status\x18\' \x01(\x0b\x32\r.xbospb.Int64\x12<\n%resistors_activated_by_aux_key_status\x18( \x01(\x0b\x32\r.xbospb.Int64\x12-\n\x16\x65vaporator_valve_state\x18) \x01(\x0b\x32\r.xbospb.Int64\x12+\n\x14output_defrost_state\x18* \x01(\x0b\x32\r.xbospb.Int64\x12\'\n\x10output_lux_state\x18+ \x01(\x0b\x32\r.xbospb.Int64\x12\'\n\x10output_aux_state\x18, \x01(\x0b\x32\r.xbospb.Int64\x12&\n\x0fresistors_state\x18- \x01(\x0b\x32\r.xbospb.Int64\x12)\n\x12output_alarm_state\x18. \x01(\x0b\x32\r.xbospb.Int64\x12.\n\x17second_compressor_state\x18/ \x01(\x0b\x32\r.xbospb.Int64\x12 \n\x08setpoint\x18\x30 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02r1\x18\x31 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02r2\x18\x32 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02r4\x18\x33 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x43\x30\x18\x34 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x43\x31\x18\x35 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x64\x30\x18\x36 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x64\x33\x18\x37 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x64\x35\x18\x38 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x64\x37\x18\x39 \x01(\x0b\x32\x0e.xbospb.Double\x12\x19\n\x02\x64\x38\x18: \x01(\x0b\x32\r.xbospb.Int64\x12\x19\n\x02\x41\x30\x18; \x01(\x0b\x32\r.xbospb.Int64\x12\x1a\n\x02\x41\x31\x18< \x01(\x0b\x32\x0e.xbospb.Double\x12\x19\n\x02\x41\x32\x18= \x01(\x0b\x32\r.xbospb.Int64\x12\x19\n\x02\x41\x33\x18> \x01(\x0b\x32\r.xbospb.Int64\x12\x1a\n\x02\x41\x34\x18? \x01(\x0b\x32\x0e.xbospb.Double\x12\x19\n\x02\x41\x35\x18@ \x01(\x0b\x32\r.xbospb.Int64\x12\x1a\n\x02\x41\x36\x18\x41 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x41\x37\x18\x42 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x41\x38\x18\x43 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1a\n\x02\x41\x39\x18\x44 \x01(\x0b\x32\x0e.xbospb.Double\x12\x19\n\x02\x46\x30\x18\x45 \x01(\x0b\x32\r.xbospb.Int64\x12\x1a\n\x02\x46\x31\x18\x46 \x01(\x0b\x32\x0e.xbospb.Double\x12\x19\n\x02\x46\x32\x18G \x01(\x0b\x32\r.xbospb.Int64\x12\x1a\n\x02\x46\x33\x18H \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd1\x18I \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd2\x18J \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd3\x18K \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd4\x18L \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd5\x18M \x01(\x0b\x32\x0e.xbospb.Double\x12\x1b\n\x03Hd6\x18N \x01(\x0b\x32\x0e.xbospb.Doubleb\x06proto3')
  ,
  dependencies=[nullabletypes__pb2.DESCRIPTOR,])




_PARKERSTATE = _descriptor.Descriptor(
  name='ParkerState',
  full_name='xbospb.ParkerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='compressor_working_hours', full_name='xbospb.ParkerState.compressor_working_hours', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_standby_status', full_name='xbospb.ParkerState.on_standby_status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_status', full_name='xbospb.ParkerState.light_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux_output_status', full_name='xbospb.ParkerState.aux_output_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_defrost_counter', full_name='xbospb.ParkerState.next_defrost_counter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='door_switch_input_status', full_name='xbospb.ParkerState.door_switch_input_status', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multipurpose_input_status', full_name='xbospb.ParkerState.multipurpose_input_status', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressor_status', full_name='xbospb.ParkerState.compressor_status', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_defrost_status', full_name='xbospb.ParkerState.output_defrost_status', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fans_status', full_name='xbospb.ParkerState.fans_status', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_k4_status', full_name='xbospb.ParkerState.output_k4_status', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cabinet_temperature', full_name='xbospb.ParkerState.cabinet_temperature', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evaporator_temperature', full_name='xbospb.ParkerState.evaporator_temperature', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxiliary_temperature', full_name='xbospb.ParkerState.auxiliary_temperature', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probe1_failure_alarm', full_name='xbospb.ParkerState.probe1_failure_alarm', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probe2_failure_alarm', full_name='xbospb.ParkerState.probe2_failure_alarm', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probe3_failure_alarm', full_name='xbospb.ParkerState.probe3_failure_alarm', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum_temperature_alarm', full_name='xbospb.ParkerState.minimum_temperature_alarm', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum_temperture_alarm', full_name='xbospb.ParkerState.maximum_temperture_alarm', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condensor_temperature_failure_alarm', full_name='xbospb.ParkerState.condensor_temperature_failure_alarm', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condensor_pre_alarm', full_name='xbospb.ParkerState.condensor_pre_alarm', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='door_alarm', full_name='xbospb.ParkerState.door_alarm', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multipurpose_input_alarm', full_name='xbospb.ParkerState.multipurpose_input_alarm', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressor_blocked_alarm', full_name='xbospb.ParkerState.compressor_blocked_alarm', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='power_failure_alarm', full_name='xbospb.ParkerState.power_failure_alarm', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rtc_error_alarm', full_name='xbospb.ParkerState.rtc_error_alarm', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy_saving_regulator_flag', full_name='xbospb.ParkerState.energy_saving_regulator_flag', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy_saving_real_time_regulator_flag', full_name='xbospb.ParkerState.energy_saving_real_time_regulator_flag', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_request_regulator_flag', full_name='xbospb.ParkerState.service_request_regulator_flag', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_standby_regulator_flag', full_name='xbospb.ParkerState.on_standby_regulator_flag', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_alarm_to_read_regulator_flag', full_name='xbospb.ParkerState.new_alarm_to_read_regulator_flag', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defrost_status_regulator_flag', full_name='xbospb.ParkerState.defrost_status_regulator_flag', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_setpoint', full_name='xbospb.ParkerState.active_setpoint', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_until_defrost', full_name='xbospb.ParkerState.time_until_defrost', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_defrost_counter', full_name='xbospb.ParkerState.current_defrost_counter', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressor_delay', full_name='xbospb.ParkerState.compressor_delay', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_alarms_in_history', full_name='xbospb.ParkerState.num_alarms_in_history', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='energy_saving_status', full_name='xbospb.ParkerState.energy_saving_status', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_request_status', full_name='xbospb.ParkerState.service_request_status', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resistors_activated_by_aux_key_status', full_name='xbospb.ParkerState.resistors_activated_by_aux_key_status', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evaporator_valve_state', full_name='xbospb.ParkerState.evaporator_valve_state', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_defrost_state', full_name='xbospb.ParkerState.output_defrost_state', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_lux_state', full_name='xbospb.ParkerState.output_lux_state', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_aux_state', full_name='xbospb.ParkerState.output_aux_state', index=43,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resistors_state', full_name='xbospb.ParkerState.resistors_state', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_alarm_state', full_name='xbospb.ParkerState.output_alarm_state', index=45,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='second_compressor_state', full_name='xbospb.ParkerState.second_compressor_state', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setpoint', full_name='xbospb.ParkerState.setpoint', index=47,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r1', full_name='xbospb.ParkerState.r1', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r2', full_name='xbospb.ParkerState.r2', index=49,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r4', full_name='xbospb.ParkerState.r4', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='C0', full_name='xbospb.ParkerState.C0', index=51,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='C1', full_name='xbospb.ParkerState.C1', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d0', full_name='xbospb.ParkerState.d0', index=53,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d3', full_name='xbospb.ParkerState.d3', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d5', full_name='xbospb.ParkerState.d5', index=55,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d7', full_name='xbospb.ParkerState.d7', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='d8', full_name='xbospb.ParkerState.d8', index=57,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A0', full_name='xbospb.ParkerState.A0', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A1', full_name='xbospb.ParkerState.A1', index=59,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A2', full_name='xbospb.ParkerState.A2', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A3', full_name='xbospb.ParkerState.A3', index=61,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A4', full_name='xbospb.ParkerState.A4', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A5', full_name='xbospb.ParkerState.A5', index=63,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A6', full_name='xbospb.ParkerState.A6', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A7', full_name='xbospb.ParkerState.A7', index=65,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A8', full_name='xbospb.ParkerState.A8', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='A9', full_name='xbospb.ParkerState.A9', index=67,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='F0', full_name='xbospb.ParkerState.F0', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='F1', full_name='xbospb.ParkerState.F1', index=69,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='F2', full_name='xbospb.ParkerState.F2', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='F3', full_name='xbospb.ParkerState.F3', index=71,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd1', full_name='xbospb.ParkerState.Hd1', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd2', full_name='xbospb.ParkerState.Hd2', index=73,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd3', full_name='xbospb.ParkerState.Hd3', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd4', full_name='xbospb.ParkerState.Hd4', index=75,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd5', full_name='xbospb.ParkerState.Hd5', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hd6', full_name='xbospb.ParkerState.Hd6', index=77,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=3117,
)

_PARKERSTATE.fields_by_name['compressor_working_hours'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['on_standby_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['light_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['aux_output_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['next_defrost_counter'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['door_switch_input_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['multipurpose_input_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['compressor_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_defrost_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['fans_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_k4_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['cabinet_temperature'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['evaporator_temperature'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['auxiliary_temperature'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['probe1_failure_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['probe2_failure_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['probe3_failure_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['minimum_temperature_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['maximum_temperture_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['condensor_temperature_failure_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['condensor_pre_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['door_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['multipurpose_input_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['compressor_blocked_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['power_failure_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['rtc_error_alarm'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['energy_saving_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['energy_saving_real_time_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['service_request_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['on_standby_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['new_alarm_to_read_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['defrost_status_regulator_flag'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['active_setpoint'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['time_until_defrost'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['current_defrost_counter'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['compressor_delay'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['num_alarms_in_history'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['energy_saving_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['service_request_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['resistors_activated_by_aux_key_status'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['evaporator_valve_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_defrost_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_lux_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_aux_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['resistors_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['output_alarm_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['second_compressor_state'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['setpoint'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['r1'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['r2'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['r4'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['C0'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['C1'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['d0'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['d3'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['d5'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['d7'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['d8'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['A0'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['A1'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['A2'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['A3'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['A4'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['A5'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['A6'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['A7'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['A8'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['A9'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['F0'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['F1'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['F2'].message_type = nullabletypes__pb2._INT64
_PARKERSTATE.fields_by_name['F3'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd1'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd2'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd3'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd4'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd5'].message_type = nullabletypes__pb2._DOUBLE
_PARKERSTATE.fields_by_name['Hd6'].message_type = nullabletypes__pb2._DOUBLE
DESCRIPTOR.message_types_by_name['ParkerState'] = _PARKERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParkerState = _reflection.GeneratedProtocolMessageType('ParkerState', (_message.Message,), dict(
  DESCRIPTOR = _PARKERSTATE,
  __module__ = 'parker_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.ParkerState)
  ))
_sym_db.RegisterMessage(ParkerState)


# @@protoc_insertion_point(module_scope)
