# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpcserver.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grpcserver.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x10grpcserver.proto\x12\x06xbospb\x1a\x19google/protobuf/any.proto\"\x83\x02\n\x11GRPCServerMessage\x12$\n\tUnaryCall\x18\x01 \x01(\x0b\x32\x11.xbospb.UnaryCall\x12,\n\rUnaryResponse\x18\x02 \x01(\x0b\x32\x15.xbospb.UnaryResponse\x12,\n\rStreamingCall\x18\x03 \x01(\x0b\x32\x15.xbospb.StreamingCall\x12\x34\n\x11StreamingResponse\x18\x04 \x01(\x0b\x32\x19.xbospb.StreamingResponse\x12\x1a\n\x04Ping\x18\x05 \x01(\x0b\x32\x0c.xbospb.Ping\x12\x1a\n\x04Pong\x18\x06 \x01(\x0b\x32\x0c.xbospb.Pong\"\x1e\n\x04Ping\x12\x16\n\x0e\x61\x63tive_queries\x18\x01 \x03(\x03\"\x06\n\x04Pong\"T\n\tUnaryCall\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x10\n\x08query_id\x18\x02 \x01(\x03\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"W\n\rUnaryResponse\x12\x10\n\x08query_id\x18\x01 \x01(\x03\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"X\n\rStreamingCall\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x10\n\x08query_id\x18\x02 \x01(\x03\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"m\n\x11StreamingResponse\x12\x10\n\x08query_id\x18\x01 \x01(\x03\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x10\n\x08\x66inished\x18\x03 \x01(\x08\x12%\n\x07payload\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x17\n\nTestParams\x12\t\n\x01x\x18\x01 \x01(\t\"\x19\n\x0cTestResponse\x12\t\n\x01x\x18\x01 \x01(\t2{\n\x04Test\x12\x37\n\tTestUnary\x12\x12.xbospb.TestParams\x1a\x14.xbospb.TestResponse\"\x00\x12:\n\nTestStream\x12\x12.xbospb.TestParams\x1a\x14.xbospb.TestResponse\"\x00\x30\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_GRPCSERVERMESSAGE = _descriptor.Descriptor(
  name='GRPCServerMessage',
  full_name='xbospb.GRPCServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='UnaryCall', full_name='xbospb.GRPCServerMessage.UnaryCall', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='UnaryResponse', full_name='xbospb.GRPCServerMessage.UnaryResponse', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='StreamingCall', full_name='xbospb.GRPCServerMessage.StreamingCall', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='StreamingResponse', full_name='xbospb.GRPCServerMessage.StreamingResponse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Ping', full_name='xbospb.GRPCServerMessage.Ping', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Pong', full_name='xbospb.GRPCServerMessage.Pong', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=315,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='xbospb.Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_queries', full_name='xbospb.Ping.active_queries', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=347,
)


_PONG = _descriptor.Descriptor(
  name='Pong',
  full_name='xbospb.Pong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=295,
)


_UNARYCALL = _descriptor.Descriptor(
  name='UnaryCall',
  full_name='xbospb.UnaryCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='xbospb.UnaryCall.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='xbospb.UnaryCall.query_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='xbospb.UnaryCall.payload', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=441,
)


_UNARYRESPONSE = _descriptor.Descriptor(
  name='UnaryResponse',
  full_name='xbospb.UnaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='xbospb.UnaryResponse.query_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='xbospb.UnaryResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='xbospb.UnaryResponse.payload', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=530,
)


_STREAMINGCALL = _descriptor.Descriptor(
  name='StreamingCall',
  full_name='xbospb.StreamingCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='xbospb.StreamingCall.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_id', full_name='xbospb.StreamingCall.query_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='xbospb.StreamingCall.payload', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=620,
)


_STREAMINGRESPONSE = _descriptor.Descriptor(
  name='StreamingResponse',
  full_name='xbospb.StreamingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_id', full_name='xbospb.StreamingResponse.query_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='xbospb.StreamingResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='xbospb.StreamingResponse.finished', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='xbospb.StreamingResponse.payload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=731,
)


_TESTPARAMS = _descriptor.Descriptor(
  name='TestParams',
  full_name='xbospb.TestParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='xbospb.TestParams.x', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=756,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='xbospb.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='xbospb.TestResponse.x', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=783,
)

_GRPCSERVERMESSAGE.fields_by_name['UnaryCall'].message_type = _UNARYCALL
_GRPCSERVERMESSAGE.fields_by_name['UnaryResponse'].message_type = _UNARYRESPONSE
_GRPCSERVERMESSAGE.fields_by_name['StreamingCall'].message_type = _STREAMINGCALL
_GRPCSERVERMESSAGE.fields_by_name['StreamingResponse'].message_type = _STREAMINGRESPONSE
_GRPCSERVERMESSAGE.fields_by_name['Ping'].message_type = _PING
_GRPCSERVERMESSAGE.fields_by_name['Pong'].message_type = _PONG
_UNARYCALL.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UNARYRESPONSE.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STREAMINGCALL.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STREAMINGRESPONSE.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['GRPCServerMessage'] = _GRPCSERVERMESSAGE
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Pong'] = _PONG
DESCRIPTOR.message_types_by_name['UnaryCall'] = _UNARYCALL
DESCRIPTOR.message_types_by_name['UnaryResponse'] = _UNARYRESPONSE
DESCRIPTOR.message_types_by_name['StreamingCall'] = _STREAMINGCALL
DESCRIPTOR.message_types_by_name['StreamingResponse'] = _STREAMINGRESPONSE
DESCRIPTOR.message_types_by_name['TestParams'] = _TESTPARAMS
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GRPCServerMessage = _reflection.GeneratedProtocolMessageType('GRPCServerMessage', (_message.Message,), dict(
  DESCRIPTOR = _GRPCSERVERMESSAGE,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.GRPCServerMessage)
  ))
_sym_db.RegisterMessage(GRPCServerMessage)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), dict(
  DESCRIPTOR = _PING,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Ping)
  ))
_sym_db.RegisterMessage(Ping)

Pong = _reflection.GeneratedProtocolMessageType('Pong', (_message.Message,), dict(
  DESCRIPTOR = _PONG,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.Pong)
  ))
_sym_db.RegisterMessage(Pong)

UnaryCall = _reflection.GeneratedProtocolMessageType('UnaryCall', (_message.Message,), dict(
  DESCRIPTOR = _UNARYCALL,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.UnaryCall)
  ))
_sym_db.RegisterMessage(UnaryCall)

UnaryResponse = _reflection.GeneratedProtocolMessageType('UnaryResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNARYRESPONSE,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.UnaryResponse)
  ))
_sym_db.RegisterMessage(UnaryResponse)

StreamingCall = _reflection.GeneratedProtocolMessageType('StreamingCall', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINGCALL,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.StreamingCall)
  ))
_sym_db.RegisterMessage(StreamingCall)

StreamingResponse = _reflection.GeneratedProtocolMessageType('StreamingResponse', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINGRESPONSE,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.StreamingResponse)
  ))
_sym_db.RegisterMessage(StreamingResponse)

TestParams = _reflection.GeneratedProtocolMessageType('TestParams', (_message.Message,), dict(
  DESCRIPTOR = _TESTPARAMS,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.TestParams)
  ))
_sym_db.RegisterMessage(TestParams)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), dict(
  DESCRIPTOR = _TESTRESPONSE,
  __module__ = 'grpcserver_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.TestResponse)
  ))
_sym_db.RegisterMessage(TestResponse)



_TEST = _descriptor.ServiceDescriptor(
  name='Test',
  full_name='xbospb.Test',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=785,
  serialized_end=908,
  methods=[
  _descriptor.MethodDescriptor(
    name='TestUnary',
    full_name='xbospb.Test.TestUnary',
    index=0,
    containing_service=None,
    input_type=_TESTPARAMS,
    output_type=_TESTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TestStream',
    full_name='xbospb.Test.TestStream',
    index=1,
    containing_service=None,
    input_type=_TESTPARAMS,
    output_type=_TESTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEST)

DESCRIPTOR.services_by_name['Test'] = _TEST

# @@protoc_insertion_point(module_scope)
