# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: weather_station.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nullabletypes_pb2 as nullabletypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='weather_station.proto',
  package='xbospb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15weather_station.proto\x12\x06xbospb\x1a\x13nullabletypes.proto\"\xd6\x05\n\x0eWeatherStation\x12\x1b\n\x04time\x18\x01 \x01(\x0b\x32\r.xbospb.Int64\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12,\n\x14nearestStormDistance\x18\x03 \x01(\x0b\x32\x0e.xbospb.Double\x12+\n\x13nearestStormBearing\x18\x04 \x01(\x0b\x32\x0e.xbospb.Double\x12\'\n\x0fprecipIntensity\x18\x05 \x01(\x0b\x32\x0e.xbospb.Double\x12,\n\x14precipIntensityError\x18\x06 \x01(\x0b\x32\x0e.xbospb.Double\x12)\n\x11precipProbability\x18\x07 \x01(\x0b\x32\x0e.xbospb.Double\x12\x12\n\nprecipType\x18\x08 \x01(\t\x12#\n\x0btemperature\x18\t \x01(\x0b\x32\x0e.xbospb.Double\x12+\n\x13\x61pparentTemperature\x18\n \x01(\x0b\x32\x0e.xbospb.Double\x12 \n\x08\x64\x65wPoint\x18\x0b \x01(\x0b\x32\x0e.xbospb.Double\x12 \n\x08humidity\x18\x0c \x01(\x0b\x32\x0e.xbospb.Double\x12 \n\x08pressure\x18\r \x01(\x0b\x32\x0e.xbospb.Double\x12!\n\twindSpeed\x18\x0e \x01(\x0b\x32\x0e.xbospb.Double\x12 \n\x08windGust\x18\x0f \x01(\x0b\x32\x0e.xbospb.Double\x12#\n\x0bwindBearing\x18\x10 \x01(\x0b\x32\x0e.xbospb.Double\x12\"\n\ncloudCover\x18\x11 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1f\n\x07uvIndex\x18\x12 \x01(\x0b\x32\x0e.xbospb.Double\x12\"\n\nvisibility\x18\x13 \x01(\x0b\x32\x0e.xbospb.Double\x12\x1d\n\x05ozone\x18\x14 \x01(\x0b\x32\x0e.xbospb.Double\"\xaf\x01\n\x18WeatherStationPrediction\x12@\n\x0bpredictions\x18\x01 \x03(\x0b\x32+.xbospb.WeatherStationPrediction.Prediction\x1aQ\n\nPrediction\x12\x17\n\x0fprediction_time\x18\x01 \x01(\x04\x12*\n\nprediction\x18\x02 \x01(\x0b\x32\x16.xbospb.WeatherStationb\x06proto3')
  ,
  dependencies=[nullabletypes__pb2.DESCRIPTOR,])




_WEATHERSTATION = _descriptor.Descriptor(
  name='WeatherStation',
  full_name='xbospb.WeatherStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='xbospb.WeatherStation.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon', full_name='xbospb.WeatherStation.icon', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nearestStormDistance', full_name='xbospb.WeatherStation.nearestStormDistance', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nearestStormBearing', full_name='xbospb.WeatherStation.nearestStormBearing', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precipIntensity', full_name='xbospb.WeatherStation.precipIntensity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precipIntensityError', full_name='xbospb.WeatherStation.precipIntensityError', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precipProbability', full_name='xbospb.WeatherStation.precipProbability', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precipType', full_name='xbospb.WeatherStation.precipType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='xbospb.WeatherStation.temperature', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apparentTemperature', full_name='xbospb.WeatherStation.apparentTemperature', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dewPoint', full_name='xbospb.WeatherStation.dewPoint', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='humidity', full_name='xbospb.WeatherStation.humidity', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pressure', full_name='xbospb.WeatherStation.pressure', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windSpeed', full_name='xbospb.WeatherStation.windSpeed', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windGust', full_name='xbospb.WeatherStation.windGust', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='windBearing', full_name='xbospb.WeatherStation.windBearing', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cloudCover', full_name='xbospb.WeatherStation.cloudCover', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uvIndex', full_name='xbospb.WeatherStation.uvIndex', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='xbospb.WeatherStation.visibility', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ozone', full_name='xbospb.WeatherStation.ozone', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=781,
)


_WEATHERSTATIONPREDICTION_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='xbospb.WeatherStationPrediction.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_time', full_name='xbospb.WeatherStationPrediction.Prediction.prediction_time', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='xbospb.WeatherStationPrediction.Prediction.prediction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=959,
)

_WEATHERSTATIONPREDICTION = _descriptor.Descriptor(
  name='WeatherStationPrediction',
  full_name='xbospb.WeatherStationPrediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predictions', full_name='xbospb.WeatherStationPrediction.predictions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_WEATHERSTATIONPREDICTION_PREDICTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=959,
)

_WEATHERSTATION.fields_by_name['time'].message_type = nullabletypes__pb2._INT64
_WEATHERSTATION.fields_by_name['nearestStormDistance'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['nearestStormBearing'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['precipIntensity'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['precipIntensityError'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['precipProbability'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['temperature'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['apparentTemperature'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['dewPoint'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['humidity'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['pressure'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['windSpeed'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['windGust'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['windBearing'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['cloudCover'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['uvIndex'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['visibility'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATION.fields_by_name['ozone'].message_type = nullabletypes__pb2._DOUBLE
_WEATHERSTATIONPREDICTION_PREDICTION.fields_by_name['prediction'].message_type = _WEATHERSTATION
_WEATHERSTATIONPREDICTION_PREDICTION.containing_type = _WEATHERSTATIONPREDICTION
_WEATHERSTATIONPREDICTION.fields_by_name['predictions'].message_type = _WEATHERSTATIONPREDICTION_PREDICTION
DESCRIPTOR.message_types_by_name['WeatherStation'] = _WEATHERSTATION
DESCRIPTOR.message_types_by_name['WeatherStationPrediction'] = _WEATHERSTATIONPREDICTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WeatherStation = _reflection.GeneratedProtocolMessageType('WeatherStation', (_message.Message,), dict(
  DESCRIPTOR = _WEATHERSTATION,
  __module__ = 'weather_station_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.WeatherStation)
  ))
_sym_db.RegisterMessage(WeatherStation)

WeatherStationPrediction = _reflection.GeneratedProtocolMessageType('WeatherStationPrediction', (_message.Message,), dict(

  Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
    DESCRIPTOR = _WEATHERSTATIONPREDICTION_PREDICTION,
    __module__ = 'weather_station_pb2'
    # @@protoc_insertion_point(class_scope:xbospb.WeatherStationPrediction.Prediction)
    ))
  ,
  DESCRIPTOR = _WEATHERSTATIONPREDICTION,
  __module__ = 'weather_station_pb2'
  # @@protoc_insertion_point(class_scope:xbospb.WeatherStationPrediction)
  ))
_sym_db.RegisterMessage(WeatherStationPrediction)
_sym_db.RegisterMessage(WeatherStationPrediction.Prediction)


# @@protoc_insertion_point(module_scope)
